@@ -20,9 +20,20 @@ sub blocks() {
     return unless defined fileno $d;
 
     seek $d, 0, 0;
+
+    my $line_offset = 0;
+
     my $content = join '', <$d>;
+
+    $content =~ s/^(.*\n__DATA__\n)/\n/s; # for win32
+    $line_offset += scalar(split /\n/, $1);
+    $content =~ s/\n__END__\n.*$/\n/s;
+
     my $parser = Text::TestBase->new();
     my @blocks = $parser->parse($content);
+    for my $block (@blocks) {
+        $block->{_lineno} += $line_offset;
+    }
     return @blocks;
 }
 
